==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/ExperimentStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ExperimentStatusFluent<A extends ExperimentStatusFluent<A>> extends Fluent<A>{
  public A addToContainerRecords(Integer index,Record item);
  public A setToContainerRecords(Integer index,Record item);
  public A addToContainerRecords(io.fabric8.chaosmesh.v1alpha1.Record... items);
  public A addAllToContainerRecords(Collection<Record> items);
  public A removeFromContainerRecords(io.fabric8.chaosmesh.v1alpha1.Record... items);
  public A removeAllFromContainerRecords(Collection<Record> items);
  public A removeMatchingFromContainerRecords(Predicate<RecordBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildContainerRecords instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Record> getContainerRecords();
  public List<Record> buildContainerRecords();
  public Record buildContainerRecord(Integer index);
  public Record buildFirstContainerRecord();
  public Record buildLastContainerRecord();
  public Record buildMatchingContainerRecord(Predicate<RecordBuilder> predicate);
  public Boolean hasMatchingContainerRecord(Predicate<RecordBuilder> predicate);
  public A withContainerRecords(List<Record> containerRecords);
  public A withContainerRecords(io.fabric8.chaosmesh.v1alpha1.Record... containerRecords);
  public Boolean hasContainerRecords();
  public A addNewContainerRecord(String id,String phase,String selectorKey);
  public ExperimentStatusFluent.ContainerRecordsNested<A> addNewContainerRecord();
  public ExperimentStatusFluent.ContainerRecordsNested<A> addNewContainerRecordLike(Record item);
  public ExperimentStatusFluent.ContainerRecordsNested<A> setNewContainerRecordLike(Integer index,Record item);
  public ExperimentStatusFluent.ContainerRecordsNested<A> editContainerRecord(Integer index);
  public ExperimentStatusFluent.ContainerRecordsNested<A> editFirstContainerRecord();
  public ExperimentStatusFluent.ContainerRecordsNested<A> editLastContainerRecord();
  public ExperimentStatusFluent.ContainerRecordsNested<A> editMatchingContainerRecord(Predicate<RecordBuilder> predicate);
  public String getDesiredPhase();
  public A withDesiredPhase(String desiredPhase);
  public Boolean hasDesiredPhase();
  public interface ContainerRecordsNested<N> extends Nested<N>,RecordFluent<ExperimentStatusFluent.ContainerRecordsNested<N>>{
    public N and();
    public N endContainerRecord();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/ExperimentStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ExperimentStatusFluent<A extends ExperimentStatusFluent<A>> extends Fluent<A>{
  public A addToContainerRecords(int index,Record item);
  public A setToContainerRecords(int index,Record item);
  public A addToContainerRecords(io.fabric8.chaosmesh.v1alpha1.Record... items);
  public A addAllToContainerRecords(Collection<Record> items);
  public A removeFromContainerRecords(io.fabric8.chaosmesh.v1alpha1.Record... items);
  public A removeAllFromContainerRecords(Collection<Record> items);
  public A removeMatchingFromContainerRecords(Predicate<RecordBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildContainerRecords instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Record> getContainerRecords();
  public List<Record> buildContainerRecords();
  public Record buildContainerRecord(int index);
  public Record buildFirstContainerRecord();
  public Record buildLastContainerRecord();
  public Record buildMatchingContainerRecord(Predicate<RecordBuilder> predicate);
  public Boolean hasMatchingContainerRecord(Predicate<RecordBuilder> predicate);
  public A withContainerRecords(List<Record> containerRecords);
  public A withContainerRecords(io.fabric8.chaosmesh.v1alpha1.Record... containerRecords);
  public Boolean hasContainerRecords();
  public A addNewContainerRecord(String id,String phase,String selectorKey);
  public ExperimentStatusFluent.ContainerRecordsNested<A> addNewContainerRecord();
  public ExperimentStatusFluent.ContainerRecordsNested<A> addNewContainerRecordLike(Record item);
  public ExperimentStatusFluent.ContainerRecordsNested<A> setNewContainerRecordLike(int index,Record item);
  public ExperimentStatusFluent.ContainerRecordsNested<A> editContainerRecord(int index);
  public ExperimentStatusFluent.ContainerRecordsNested<A> editFirstContainerRecord();
  public ExperimentStatusFluent.ContainerRecordsNested<A> editLastContainerRecord();
  public ExperimentStatusFluent.ContainerRecordsNested<A> editMatchingContainerRecord(Predicate<RecordBuilder> predicate);
  public String getDesiredPhase();
  public A withDesiredPhase(String desiredPhase);
  public Boolean hasDesiredPhase();
  public interface ContainerRecordsNested<N> extends Nested<N>,RecordFluent<ExperimentStatusFluent.ContainerRecordsNested<N>>{
    public N and();
    public N endContainerRecord();
    
  }
  
}
